==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/disposes/beans/DependentModelProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.disposes.beans;

import javax.annotation.PreDestroy;
import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.context.Dependent;
import javax.enterprise.inject.Disposes;
import javax.enterprise.inject.Produces;

import org.apache.webbeans.test.disposes.common.DependentModel;
import org.apache.webbeans.test.disposes.common.HttpHeader;

@ApplicationScoped
public class DependentModelProducer
{
    public static int disposerCount = 0;

    public static boolean producerGotDestroyed = false;

    @Produces @Dependent @HttpHeader
    public static DependentModel dproduce()
    {
        System.out.println("produced DependentModel from DepenentProducer");
        return new DependentModel();
    }
    
    
    public static void ddispose(@Disposes @HttpHeader DependentModel model)
    {
        DependentModelProducer.disposerCount++;
        System.out.println("disposed DependentModel from DependentDisposer");
    }

    @PreDestroy
    public void destroyMe()
    {
        producerGotDestroyed = true;
    }

}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/disposes/beans/DependentModelProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.disposes.beans;

import jakarta.annotation.PreDestroy;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.context.Dependent;
import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;

import org.apache.webbeans.test.disposes.common.DependentModel;
import org.apache.webbeans.test.disposes.common.HttpHeader;

@ApplicationScoped
public class DependentModelProducer
{
    public static int disposerCount = 0;

    public static boolean producerGotDestroyed = false;

    @Produces @Dependent @HttpHeader
    public static DependentModel dproduce()
    {
        System.out.println("produced DependentModel from DepenentProducer");
        return new DependentModel();
    }
    
    
    public static void ddispose(@Disposes @HttpHeader DependentModel model)
    {
        DependentModelProducer.disposerCount++;
        System.out.println("disposed DependentModel from DependentDisposer");
    }

    @PreDestroy
    public void destroyMe()
    {
        producerGotDestroyed = true;
    }

}
